@@ -24,7 +24,7 @@
 #define WITH_SIMD
 #define WITH_AVX2
 #define WITH_CUPS
-#define WITH_JPEG
+/* #undef WITH_JPEG */
 /* #undef WITH_WIN8 */
 /* #undef WITH_AAD */
 /* #undef WITH_CAIRO */
@@ -35,7 +35,7 @@
 /* #undef WITH_MACAUDIO */
 /* #undef WITH_OSS */
 #define WITH_ALSA
-#define WITH_PULSE
+/* #undef WITH_PULSE */
 /* #undef WITH_IOSAUDIO */
 /* #undef WITH_OPENSLES */
 /* #undef WITH_GSM */
